/**
 * @file ProcessSessionFactory.h
 * ProcessSessionFactory class declaration
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#pragma once

#include <memory>

#include "minifi-cpp/core/ProcessContext.h"
#include "ProcessSession.h"
#include "minifi-cpp/core/ProcessSessionFactory.h"

namespace org::apache::nifi::minifi::core {

class ProcessSessionFactoryImpl : public virtual ProcessSessionFactory {
 public:
  explicit ProcessSessionFactoryImpl(std::shared_ptr<ProcessContext> processContext)
      : process_context_(processContext) {
  }

  std::shared_ptr<ProcessSession> createSession() override;

  ProcessSessionFactoryImpl(const ProcessSessionFactoryImpl &parent) = delete;
  ProcessSessionFactoryImpl &operator=(const ProcessSessionFactoryImpl &parent) = delete;

  ~ProcessSessionFactoryImpl() override = default;

 private:
  std::shared_ptr<ProcessContext> process_context_;
};

}  // namespace org::apache::nifi::minifi::core
